==> ZenTaoPMS.max2.0.rc1.php5.3_5.6.zip: zentaopms/module/upgrade/ext/lang/zh-tw/zentaobiz.php <==
<?php
$lang->upgrade->fromVersions['pro10_0_rc1'] = 'pro10.0.rc1';

$lang->upgrade->fromVersions['biz1_0']       = 'Biz1.0';
$lang->upgrade->fromVersions['biz1_1']       = 'Biz1.1';
$lang->upgrade->fromVersions['biz1_1_1']     = 'Biz1.1.1';
$lang->upgrade->fromVersions['biz1_1_2']     = 'Biz1.1.2';
$lang->upgrade->fromVersions['biz1_1_3']     = 'Biz1.1.3';
$lang->upgrade->fromVersions['biz1_1_4']     = 'Biz1.1.4';
$lang->upgrade->fromVersions['biz2_0_beta']  = 'Biz2.0.beta';
$lang->upgrade->fromVersions['biz2_1']       = 'Biz2.1';
$lang->upgrade->fromVersions['biz2_2']       = 'Biz2.2';
$lang->upgrade->fromVersions['biz2_3']       = 'Biz2.3';
$lang->upgrade->fromVersions['biz2_3_1']     = 'Biz2.3.1';
$lang->upgrade->fromVersions['biz2_4']       = 'Biz2.4';
$lang->upgrade->fromVersions['biz3_0']       = 'Biz3.0';
$lang->upgrade->fromVersions['biz3_1']       = 'Biz3.1';
$lang->upgrade->fromVersions['biz3_2']       = 'Biz3.2';
$lang->upgrade->fromVersions['biz3_2_1']     = 'Biz3.2.1';
$lang->upgrade->fromVersions['biz3_3']       = 'Biz3.3';
$lang->upgrade->fromVersions['biz3_4']       = 'Biz3.4';
$lang->upgrade->fromVersions['biz3_5_alpha'] = 'Biz3.5.alpha';
$lang->upgrade->fromVersions['biz3_5_beta']  = 'Biz3.5.beta';
$lang->upgrade->fromVersions['biz3_5']       = 'Biz3.5';
$lang->upgrade->fromVersions['biz3_5_1']     = 'Biz3.5.1';
$lang->upgrade->fromVersions['biz3_6']       = 'Biz3.6';
$lang->upgrade->fromVersions['biz3_6_1']     = 'Biz3.6.1';
$lang->upgrade->fromVersions['biz3_7']       = 'Biz3.7';
$lang->upgrade->fromVersions['biz3_7_1']     = 'Biz3.7.1';
$lang->upgrade->fromVersions['biz3_7_2']     = 'Biz3.7.2';
$lang->upgrade->fromVersions['biz4_0']       = 'Biz4.0';
$lang->upgrade->fromVersions['biz4_0_1']     = 'Biz4.0.1';
$lang->upgrade->fromVersions['biz4_0_2']     = 'Biz4.0.2';
$lang->upgrade->fromVersions['biz4_0_3']     = 'Biz4.0.3';
$lang->upgrade->fromVersions['biz4_0_4']     = 'Biz4.0.4';
$lang->upgrade->fromVersions['biz4_1']       = 'Biz4.1';
$lang->upgrade->fromVersions['biz4_1_1']     = 'Biz4.1.1';
$lang->upgrade->fromVersions['biz4_1_2']     = 'Biz4.1.2';
$lang->upgrade->fromVersions['biz4_1_3']     = 'Biz4.1.3';

==> ZenTaoPMS.max2.7.php7.0.zip: zentaopms/module/upgrade/ext/lang/zh-tw/zentaobiz.php <==
<?php
$lang->upgrade->fromVersions['pro11_0'] = 'Pro11.0';

$lang->upgrade->fromVersions['biz1_0']       = 'Biz1.0';
$lang->upgrade->fromVersions['biz1_1']       = 'Biz1.1';
$lang->upgrade->fromVersions['biz1_1_1']     = 'Biz1.1.1';
$lang->upgrade->fromVersions['biz1_1_2']     = 'Biz1.1.2';
$lang->upgrade->fromVersions['biz1_1_3']     = 'Biz1.1.3';
$lang->upgrade->fromVersions['biz1_1_4']     = 'Biz1.1.4';
$lang->upgrade->fromVersions['biz2_0_beta']  = 'Biz2.0.beta';
$lang->upgrade->fromVersions['biz2_1']       = 'Biz2.1';
$lang->upgrade->fromVersions['biz2_2']       = 'Biz2.2';
$lang->upgrade->fromVersions['biz2_3']       = 'Biz2.3';
$lang->upgrade->fromVersions['biz2_3_1']     = 'Biz2.3.1';
$lang->upgrade->fromVersions['biz2_4']       = 'Biz2.4';
$lang->upgrade->fromVersions['biz3_0']       = 'Biz3.0';
$lang->upgrade->fromVersions['biz3_1']       = 'Biz3.1';
$lang->upgrade->fromVersions['biz3_2']       = 'Biz3.2';
$lang->upgrade->fromVersions['biz3_2_1']     = 'Biz3.2.1';
$lang->upgrade->fromVersions['biz3_3']       = 'Biz3.3';
$lang->upgrade->fromVersions['biz3_4']       = 'Biz3.4';
$lang->upgrade->fromVersions['biz3_5_alpha'] = 'Biz3.5.alpha';
$lang->upgrade->fromVersions['biz3_5_beta']  = 'Biz3.5.beta';
$lang->upgrade->fromVersions['biz3_5']       = 'Biz3.5';
$lang->upgrade->fromVersions['biz3_5_1']     = 'Biz3.5.1';
$lang->upgrade->fromVersions['biz3_6']       = 'Biz3.6';
$lang->upgrade->fromVersions['biz3_6_1']     = 'Biz3.6.1';
$lang->upgrade->fromVersions['biz3_7']       = 'Biz3.7';
$lang->upgrade->fromVersions['biz3_7_1']     = 'Biz3.7.1';
$lang->upgrade->fromVersions['biz3_7_2']     = 'Biz3.7.2';
$lang->upgrade->fromVersions['biz4_0']       = 'Biz4.0';
$lang->upgrade->fromVersions['biz4_0_1']     = 'Biz4.0.1';
$lang->upgrade->fromVersions['biz4_0_2']     = 'Biz4.0.2';
$lang->upgrade->fromVersions['biz4_0_3']     = 'Biz4.0.3';
$lang->upgrade->fromVersions['biz4_0_4']     = 'Biz4.0.4';
$lang->upgrade->fromVersions['biz4_1']       = 'Biz4.1';
$lang->upgrade->fromVersions['biz4_1_1']     = 'Biz4.1.1';
$lang->upgrade->fromVersions['biz4_1_2']     = 'Biz4.1.2';
$lang->upgrade->fromVersions['biz4_1_3']     = 'Biz4.1.3';
$lang->upgrade->fromVersions['biz5_0_rc1']   = 'Biz5.0.rc1';
$lang->upgrade->fromVersions['biz5_0']       = 'Biz5.0';
$lang->upgrade->fromVersions['biz5_0_1']     = 'Biz5.0.1';
$lang->upgrade->fromVersions['biz5_1']       = 'Biz5.1';
$lang->upgrade->fromVersions['biz5_2']       = 'Biz5.2';
$lang->upgrade->fromVersions['biz5_3']       = 'Biz5.3';
$lang->upgrade->fromVersions['biz5_3_1']     = 'Biz5.3.1';
$lang->upgrade->fromVersions['biz6_0_beta1'] = 'Biz6.0.beta1';
$lang->upgrade->fromVersions['biz6_0']       = 'Biz6.0';
$lang->upgrade->fromVersions['biz6_1']       = 'Biz6.1';
$lang->upgrade->fromVersions['biz6_2']       = 'Biz6.2';
